==> kubernetes-model-0.1.1-sources.jar: io/fabric8/kubernetes/api/model/TCPSocketActionFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class TCPSocketActionFluent<T extends TCPSocketActionFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     VisitableBuilder<IntOrString, ?> port;     Map<String, Object> additionalProperties = new HashMap();

    public IntOrString getPort(){
    return this.port!=null?this.port.build():null;
    }
    public T withPort( IntOrString port){
    if (port!=null){ this.port= new IntOrStringBuilder(port); _visitables.add(this.port);} return (T) this;
    }
    public PortNested<T> withNewPort(){
    return new PortNested<T>();
    }
    public PortNested<T> withNewPortLike( IntOrString item){
    return new PortNested<T>(item);
    }
    public PortNested<T> editPort(){
    return withNewPortLike(getPort());
    }
    public T withNewPort( String strVal){
    return withPort(new IntOrString(strVal));
    }
    public T withNewPort( Integer intVal){
    return withPort(new IntOrString(intVal));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }

    public class PortNested<N> extends IntOrStringFluent<PortNested<N>> implements Nested<N>{

        private final IntOrStringBuilder builder;
    
             PortNested (){
        this.builder = new IntOrStringBuilder(this);
        }
             PortNested ( IntOrString item){
        this.builder = new IntOrStringBuilder(this, item);
        }
    
            public N and(){
            return (N) TCPSocketActionFluent.this.withPort(builder.build());
        }
            public N endPort(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.23-sources.jar: io/fabric8/kubernetes/api/model/TCPSocketActionFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;

public class TCPSocketActionFluent<T extends TCPSocketActionFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     VisitableBuilder<IntOrString, ?> port;     Map<String, Object> additionalProperties = new HashMap();

    public IntOrString getPort(){
    return this.port!=null?this.port.build():null;
    }
    public T withPort( IntOrString port){
    if (port!=null){ this.port= new IntOrStringBuilder(port); _visitables.add(this.port);} return (T) this;
    }
    public PortNested<T> withNewPort(){
    return new PortNested<T>();
    }
    public PortNested<T> withNewPortLike( IntOrString item){
    return new PortNested<T>(item);
    }
    public PortNested<T> editPort(){
    return withNewPortLike(getPort());
    }
    public T withNewPort( Integer intVal){
    return withPort(new IntOrString(intVal));
    }
    public T withNewPort( String strVal){
    return withPort(new IntOrString(strVal));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
TCPSocketActionFluent that = (TCPSocketActionFluent) o;
if (port != null ? !port.equals(that.port) :that.port != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class PortNested<N> extends IntOrStringFluent<PortNested<N>> implements Nested<N>{

        private final IntOrStringBuilder builder;
    
             PortNested ( IntOrString item){
        this.builder = new IntOrStringBuilder(this, item);
        }
             PortNested (){
        this.builder = new IntOrStringBuilder(this);
        }
    
            public N endPort(){
            return and();
        }
            public N and(){
            return (N) TCPSocketActionFluent.this.withPort(builder.build());
        }
    
}


}
